#include "RooGlobalFunc.h"
#include "RooRealVar.h"
#include "RooArgList.h"
#include "RooFormulaVar.h"
#include "RooDataSet.h"
#include "RooGaussian.h"
#include "RooAddModel.h"
#include "RooProdPdf.h"
#include "TCanvas.h"
#include "RooPlot.h"
#include "RooHist.h"
#include "RooPolynomial.h"
#include "RooBinning.h"
#include "RooPolyVar.h"
#include "TH1.h"
#include "TH2.h"
#include "RooAddPdf.h"
#include "RooProdPdf.h"
#include "RooFitResult.h"
#include "RooGenericPdf.h"
#include "RooLandau.h"
#include "TChain.h"
#include "TCanvas.h"
#include "TAxis.h"
#include "RooPlot.h"
#include "RooCategory.h"
#include "RooSuperCategory.h"
#include "RooSimultaneous.h"
#include "RooNLLVar.h"
#include "RooMCStudy.h"
#include "TFile.h"
#include "RooJohnson.h"
#include "TRandom3.h"
#include "RooBinning.h"
#include "RooDataHist.h"
#include "RooExponential.h"
#include "RooChebychev.h"
#include "RooDstD0BG.h"
#include "myRooPolBG.cpp"
#include "myRooJohnsonSU.cpp"

using namespace RooFit ;
using namespace std;

void kk_toystudy_belle()
{
  //The Variables
  RooRealVar mD0pi("mD0pi","", 2.005, 2.025, "");
  RooRealVar mKK("mKK","", 1.75, 2.05, "");
  RooRealVar weights("weights","", 0.5, 3, "");

  //Variable used to separate the total sample into two (should be there in the tree)
  RooRealVar pisoft("pisoft","",-2,2,"");

  //Separated datasets
  // RooDataSet *dataxy_d0    = new RooDataSet("data_d0","data_d0",tree,RooArgSet(mKK,mD0pi,pisoft,weights),"pisoft==1");
  // RooDataSet *dataxy_d0bar = new RooDataSet("data_d0bar","data_d0bar",tree,RooArgSet(mKK,mD0pi,pisoft,weights),"pisoft==-1");

  /*-----------------------S I G N A L----------------------*/

  //d0pi
  RooRealVar f_J_sig_d0pi("f_{J_sig_d0pi}", "rel_frac_j",4.39599e-01);
  RooRealVar A_fJ_sig_d0pi("A_{fJ_sig_d0pi}","",0);
  RooFormulaVar f_J_sig_d0pi_d0("f_J_sig_d0pi_d0","","(@0*(1 + @1))",RooArgList(f_J_sig_d0pi,A_fJ_sig_d0pi));
  RooFormulaVar f_J_sig_d0pi_d0bar("f_J_sig_d0pi_d0bar","","(@0*(1- @1))",RooArgList(f_J_sig_d0pi,A_fJ_sig_d0pi));

  RooRealVar mu_J_sig_d0pi("#mu_{J_sig_d0pi}","mean_johnson",2.01024e+00,2.009,2.011);
  RooRealVar A_mu_J_sig_d0pi("A_{mu_J_sig_d0pi}","",0);
  RooFormulaVar mu_J_sig_d0pi_d0("mu_J_sig_d0pi_d0","","(@0*(1 + @1))",RooArgList(mu_J_sig_d0pi, A_mu_J_sig_d0pi));
  RooFormulaVar mu_J_sig_d0pi_d0bar("mu_J_sig_d0pi_d0bar","","(@0*(1- @1))",RooArgList(mu_J_sig_d0pi, A_mu_J_sig_d0pi));

  RooRealVar sigma_J_sig_d0pi("#sigma_{J_sig_d0pi}", "sigma_johnson",2.35832e-04);
  RooRealVar A_sigma_J_sig_d0pi("A_{sigma_J_sig_d0pi}","",0);
  RooFormulaVar sigma_J_sig_d0pi_d0("sigma_J_sig_d0pi_d0","","(@0*(1 + @1))",RooArgList(sigma_J_sig_d0pi, A_sigma_J_sig_d0pi));
  RooFormulaVar sigma_J_sig_d0pi_d0bar("sigma_J_sig_d0pi_d0bar","","(@0*(1- @1))",RooArgList(sigma_J_sig_d0pi, A_sigma_J_sig_d0pi));

  RooRealVar gamma_J_sig_d0pi("#gamma_{J_sig_d0pi}", "gamma",-2.02236e-01);
  RooRealVar A_gamma_J_sig_d0pi("A_{gamma_J_sig_d0pi}","",0);
  RooFormulaVar gamma_J_sig_d0pi_d0("gamma_J_sig_d0pi_d0","","(@0*(1 + @1))",RooArgList(gamma_J_sig_d0pi, A_gamma_J_sig_d0pi));
  RooFormulaVar gamma_J_sig_d0pi_d0bar("gamma_J_sig_d0pi_d0bar","","(@0*(1- @1))",RooArgList(gamma_J_sig_d0pi, A_gamma_J_sig_d0pi));

  RooRealVar delta_J_sig_d0pi("#delta_{J_sig_d0pi}", "delta", 9.49540e-01);
  RooRealVar A_delta_J_sig_d0pi("A_{delta_J_sig_d0pi}","",0);
  RooFormulaVar delta_J_sig_d0pi_d0("delta_J_sig_d0pi_d0","","(@0*(1 + @1))",RooArgList(delta_J_sig_d0pi, A_delta_J_sig_d0pi));
  RooFormulaVar delta_J_sig_d0pi_d0bar("delta_J_sig_d0pi_d0bar","","(@0*(1- @1))",RooArgList(delta_J_sig_d0pi, A_delta_J_sig_d0pi));

  myRooJohnsonSU johnson_sig_d0pi_d0("johnson_sig_d0pi_d0","johnson_sig_d0", mD0pi, mu_J_sig_d0pi_d0, sigma_J_sig_d0pi_d0, delta_J_sig_d0pi_d0, gamma_J_sig_d0pi_d0);
  myRooJohnsonSU johnson_sig_d0pi_d0bar("johnson_sig_d0pi_d0bar","johnson_sig_d0bar", mD0pi, mu_J_sig_d0pi_d0bar, sigma_J_sig_d0pi_d0bar, delta_J_sig_d0pi_d0bar, gamma_J_sig_d0pi_d0bar);
  
  RooRealVar f_G1_sig_d0pi("f_{G1sig_d0pi}", "frac_gauss1",3.26131e-01);
  RooRealVar A_f_G1_sig_d0pi("A_{f_G1_sig_d0pi}","",0);
  RooFormulaVar f_G1_sig_d0pi_d0("f_G1_sig_d0pi_d0","","(@0*(1 + @1))",RooArgList(f_G1_sig_d0pi, A_f_G1_sig_d0pi));
  RooFormulaVar f_G1_sig_d0pi_d0bar("f_G1_sig_d0pi_d0bar","","(@0*(1- @1))",RooArgList(f_G1_sig_d0pi, A_f_G1_sig_d0pi));

  RooRealVar mu_G1_sig_d0pi("#mu_{G1sig_d0pi}", "mean_gauss1",2.01025e+00);
  RooRealVar A_mu_G1_sig_d0pi("A_{mu_G1_sig_d0pi}","",0);
  RooFormulaVar mu_G1_sig_d0pi_d0("mu_G1_sig_d0pi_d0","","(@0*(1 + @1))",RooArgList(mu_G1_sig_d0pi, A_mu_G1_sig_d0pi));
  RooFormulaVar mu_G1_sig_d0pi_d0bar("mu_G1_sig_d0pi_d0bar","","(@0*(1- @1))",RooArgList(mu_G1_sig_d0pi, A_mu_G1_sig_d0pi));

  RooRealVar sigma_G1_sig_d0pi("#sigma_{G1sig_d0pi}", "sigma_gauss1",3.76484e-04);
  RooRealVar A_sigma_G1_sig_d0pi("A_{sigma_G1_sig_d0pi}","",0);
  RooFormulaVar sigma_G1_sig_d0pi_d0("sigma_G1_sig_d0pi_d0","","(@0*(1 + @1))",RooArgList(sigma_G1_sig_d0pi, A_sigma_G1_sig_d0pi));
  RooFormulaVar sigma_G1_sig_d0pi_d0bar("sigma_G1_sig_d0pi_d0bar","","(@0*(1- @1))",RooArgList(sigma_G1_sig_d0pi, A_sigma_G1_sig_d0pi));

  RooRealVar sigma_G2_sig_d0pi("#sigma_{G2sig_d0pi}", "sigma_gauss2",2.21655e-04);
  RooRealVar A_sigma_G2_sig_d0pi("A_{sigma_G2_sig_d0pi}","",0);
  RooFormulaVar sigma_G2_sig_d0pi_d0("sigma_G2_sig_d0pi_d0","","(@0*(1 + @1))",RooArgList(sigma_G2_sig_d0pi, A_sigma_G2_sig_d0pi));
  RooFormulaVar sigma_G2_sig_d0pi_d0bar("sigma_G2_sig_d0pi_d0bar","","(@0*(1- @1))",RooArgList(sigma_G2_sig_d0pi, A_sigma_G2_sig_d0pi));

  RooGaussian gauss1_sig_d0pi_d0("gauss1_sig_d0pi_d0", "1st gaussian PDF", mD0pi, mu_G1_sig_d0pi_d0, sigma_G1_sig_d0pi_d0);
  RooGaussian gauss1_sig_d0pi_d0bar("gauss1_sig_d0pi_d0bar", "1st gaussian PDF", mD0pi, mu_G1_sig_d0pi_d0bar, sigma_G1_sig_d0pi_d0bar);
  RooGaussian gauss2_sig_d0pi_d0("gauss2_sig_d0pi_d0", "2nd gaussian PDF", mD0pi, mu_G1_sig_d0pi_d0, sigma_G2_sig_d0pi_d0);
  RooGaussian gauss2_sig_d0pi_d0bar("gauss2_sig_d0pi_d0bar", "2nd gaussian PDF", mD0pi, mu_G1_sig_d0pi_d0bar, sigma_G2_sig_d0pi_d0bar);
  
  RooAddPdf doublegaussian_sig_d0pi_d0("doublegaussian_sig_d0", "doublegaussian_sig", gauss1_sig_d0pi_d0, gauss2_sig_d0pi_d0, f_G1_sig_d0pi_d0);
  RooAddPdf doublegaussian_sig_d0pi_d0bar("doublegaussian_sig_d0bar", "doublegaussian_sig", gauss1_sig_d0pi_d0bar, gauss2_sig_d0pi_d0bar, f_G1_sig_d0pi_d0bar);
  
  RooAddPdf sig_mD0pi_d0("sig_mD0pi_d0","sig_mD0pi_d0", johnson_sig_d0pi_d0, doublegaussian_sig_d0pi_d0, f_J_sig_d0pi_d0);
  RooAddPdf sig_mD0pi_d0bar("sig_mD0pi_d0bar","sig_mD0pi_d0bar", johnson_sig_d0pi_d0bar, doublegaussian_sig_d0pi_d0bar, f_J_sig_d0pi_d0bar);
  
  //kk
  RooRealVar f_J_sig_dz("f_{J_sig_dz}", "relative_frac_j",9.80741e-01);
  RooRealVar A_f_J_sig_dz("A_{f_J_sig_dz}","",0);
  RooFormulaVar f_J_sig_dz_d0("f_J_sig_dz_d0","","(@0*(1 + @1))",RooArgList(f_J_sig_dz, A_f_J_sig_dz));
  RooFormulaVar f_J_sig_dz_d0bar("f_J_sig_dz_d0bar","","(@0*(1- @1))",RooArgList(f_J_sig_dz, A_f_J_sig_dz));

  RooRealVar mu_J_sig_dz("#mu_{J_sig_dz}","mean_johnson",1.86436e+00,1.85,1.87);
  RooRealVar A_mu_J_sig_dz("A_{mu_J_sig_dz}","",0);
  RooFormulaVar mu_J_sig_dz_d0("mu_J_sig_dz_d0","","(@0*(1 + @1))",RooArgList(mu_J_sig_dz, A_mu_J_sig_dz));
  RooFormulaVar mu_J_sig_dz_d0bar("mu_J_sig_dz_d0bar","","(@0*(1- @1))",RooArgList(mu_J_sig_dz, A_mu_J_sig_dz));

  RooRealVar sigma_J_sig_dz("#sigma_{J_sig_dz}", "sigma_johnson",9.51422e-03,0,1);
  RooRealVar A_sigma_J_sig_dz("A_{sigma_J_sig_dz}","",0);
  RooFormulaVar sigma_J_sig_dz_d0("sigma_J_sig_dz_d0","","(@0*(1 + @1))",RooArgList(sigma_J_sig_dz, A_sigma_J_sig_dz));
  RooFormulaVar sigma_J_sig_dz_d0bar("sigma_J_sig_dz_d0bar","","(@0*(1- @1))",RooArgList(sigma_J_sig_dz, A_sigma_J_sig_dz));

  RooRealVar gamma_J_sig_dz("#gamma_{J_sig_dz}", "gamma",-1.24780e-01);
  RooRealVar A_gamma_J_sig_dz("A_{gamma_J_sig_dz}","",0);
  RooFormulaVar gamma_J_sig_dz_d0("gamma_J_sig_dz_d0","","(@0*(1 + @1))",RooArgList(gamma_J_sig_dz, A_gamma_J_sig_dz));
  RooFormulaVar gamma_J_sig_dz_d0bar("gamma_J_sig_dz_d0bar","","(@0*(1- @1))",RooArgList(gamma_J_sig_dz, A_gamma_J_sig_dz));

  RooRealVar delta_J_sig_dz("#delta_{J_sig_dz}", "delta",1.95358e+00,0,5);
  RooRealVar A_delta_J_sig_dz("A_{delta_J_sig_dz}","",0);
  RooFormulaVar delta_J_sig_dz_d0("delta_J_sig_dz_d0","","(@0*(1 + @1))",RooArgList(delta_J_sig_dz, A_delta_J_sig_dz));
  RooFormulaVar delta_J_sig_dz_d0bar("delta_J_sig_dz_d0bar","","(@0*(1- @1))",RooArgList(delta_J_sig_dz, A_delta_J_sig_dz));

  myRooJohnsonSU johnson_sig_dz_d0("johnson_sig_dz_d0", "johnson_sig_dz_d0", mKK, mu_J_sig_dz_d0, sigma_J_sig_dz_d0, delta_J_sig_dz_d0, gamma_J_sig_dz_d0);
  myRooJohnsonSU johnson_sig_dz_d0bar("johnson_sig_dz_d0bar", "johnson_sig_dz_d0bar", mKK, mu_J_sig_dz_d0bar, sigma_J_sig_dz_d0bar, delta_J_sig_dz_d0bar, gamma_J_sig_dz_d0bar);
  
  RooRealVar f_G1_sig_dz("f_{G1}_sig_dz", "relative_frac_g",1.78465e-01);
  RooRealVar A_f_G1_sig_dz("A_{f_G1_sig_dz}","",0);
  RooFormulaVar f_G1_sig_dz_d0("f_G1_sig_dz_d0","","(@0*(1 + @1))",RooArgList(f_G1_sig_dz, A_f_G1_sig_dz));
  RooFormulaVar f_G1_sig_dz_d0bar("f_G1_sig_dz_d0bar","","(@0*(1- @1))",RooArgList(f_G1_sig_dz, A_f_G1_sig_dz));

  RooRealVar mu_G1_sig_dz("#mu_{G1}_sig_dz", "mean_gauss1",1.83931e+00);
  RooRealVar A_mu_G1_sig_dz("A_{mu_G1_sig_dz}","",0);
  RooFormulaVar mu_G1_sig_dz_d0("mu_G1_sig_dz_d0","","(@0*(1 + @1))",RooArgList(mu_G1_sig_dz, A_mu_G1_sig_dz));
  RooFormulaVar mu_G1_sig_dz_d0bar("mu_G1_sig_dz_d0bar","","(@0*(1- @1))",RooArgList(mu_G1_sig_dz, A_mu_G1_sig_dz));

  RooRealVar sigma_G1_sig_dz("#sigma_{G1}_sig_dz", "sigma_gauss1",7.54561e-03);
  RooRealVar A_sigma_G1_sig_dz("A_{sigma_G1_sig_dz}","",0);
  RooFormulaVar sigma_G1_sig_dz_d0("sigma_G1_sig_dz_d0","","(@0*(1 + @1))",RooArgList(sigma_G1_sig_dz, A_sigma_G1_sig_dz));
  RooFormulaVar sigma_G1_sig_dz_d0bar("sigma_G1_sig_dz_d0bar","","(@0*(1- @1))",RooArgList(sigma_G1_sig_dz, A_sigma_G1_sig_dz));
  
  RooRealVar sigma_G2_sig_dz("#sigma_{G2}_sig_dz", "sigma_gauss2",4.47656e-02);
  RooRealVar A_sigma_G2_sig_dz("A_{sigma_G2_sig_dz}","",0);
  RooFormulaVar sigma_G2_sig_dz_d0("sigma_G2_sig_dz_d0","","(@0*(1 + @1))",RooArgList(sigma_G2_sig_dz, A_sigma_G2_sig_dz));
  RooFormulaVar sigma_G2_sig_dz_d0bar("sigma_G2_sig_dz_d0bar","","(@0*(1- @1))",RooArgList(sigma_G2_sig_dz, A_sigma_G2_sig_dz));

  RooGaussian gauss1_sig_dz_d0("gauss1_sig_dz_d0", "1st gaussian PDF", mKK, mu_G1_sig_dz_d0, sigma_G1_sig_dz_d0);
  RooGaussian gauss1_sig_dz_d0bar("gauss1_sig_dz_d0bar", "1st gaussian PDF", mKK, mu_G1_sig_dz_d0bar, sigma_G1_sig_dz_d0bar);
  
  RooGaussian gauss2_sig_dz_d0("gauss2_sig_dz_d0", "2nd gaussian PDF", mKK, mu_G1_sig_dz_d0, sigma_G2_sig_dz_d0);
  RooGaussian gauss2_sig_dz_d0bar("gauss2_sig_dz_d0bar", "2nd gaussian PDF", mKK, mu_G1_sig_dz_d0bar, sigma_G2_sig_dz_d0bar);

  RooAddPdf doublegaussian_sig_dz_d0("doublegaussian_sig_dz_d0", "doublegaussian_sig_dz_d0", gauss1_sig_dz_d0, gauss2_sig_dz_d0, f_G1_sig_dz_d0);
  RooAddPdf doublegaussian_sig_dz_d0bar("doublegaussian_sig_dz_d0bar", "doublegaussian_sig_dz_d0bar", gauss1_sig_dz_d0bar, gauss2_sig_dz_d0bar, f_G1_sig_dz_d0bar);
  
  RooAddPdf sig_mKK_d0("sig_mKK_d0","sig_mKK_d0", johnson_sig_dz_d0, doublegaussian_sig_dz_d0, f_J_sig_dz_d0);
  RooAddPdf sig_mKK_d0bar("sig_mKK_d0bar","sig_mKK_d0bar", johnson_sig_dz_d0bar, doublegaussian_sig_dz_d0bar, f_J_sig_dz_d0bar);
  
  //signal peak
  RooProdPdf signal_peak_d0("signal_peak_d0", "signal_peak_d0", sig_mKK_d0, sig_mD0pi_d0);
  RooProdPdf signal_peak_d0bar("signal_peak_d0bar", "signal_peak_d0bar", sig_mKK_d0bar, sig_mD0pi_d0bar);
  
  //random pion (common for all)
  RooRealVar m0("m0", "no data beyond this", 2.00441);
  RooRealVar kappa("C", "C", 2.23589e-03,-1e6,1e6);
  RooRealVar alpha("A", "A", 1.93367e+01,0,1e6);
  RooRealVar beta("B",  "B" ,0);
  RooDstD0BG bkg_mD0pi("bkg_mD0pi","bkg_mD0pi", mD0pi, m0, kappa, alpha, beta);
  
  //signal & random pion
  RooProdPdf signal_rnd_d0("signal_rnd_d0", "signal_rnd_d0", sig_mKK_d0, bkg_mD0pi);
  RooProdPdf signal_rnd_d0bar("signal_rnd_d0bar", "signal_rnd_d0bar", sig_mKK_d0bar, bkg_mD0pi);

  /*-----------------------K Pi-------------------------*/

  //kk
  RooRealVar f1_d0kpi("f_{G_kpi}", "relative fraction gaussian",3.09861e-01,0,1);
  RooRealVar A_f1_d0kpi("A_{f1_d0kpi}","",0);
  RooFormulaVar f1_d0kpi_d0("f1_d0kpi_d0","","(@0*(1 + @1))",RooArgList(f1_d0kpi, A_f1_d0kpi));
  RooFormulaVar f1_d0kpi_d0bar("f1_d0kpi_d0bar","","(@0*(1- @1))",RooArgList(f1_d0kpi, A_f1_d0kpi));

  RooRealVar mu_G_d0kpi("#mu_{G_kpi}","mean_gaus",1.94463e+00);
  RooRealVar A_mu_G_d0kpi("A_{mu_G_d0kpi}","",0);
  RooFormulaVar mu_G_d0kpi_d0("mu_G_d0kpi_d0","","(@0*(1 + @1))",RooArgList(mu_G_d0kpi, A_mu_G_d0kpi));
  RooFormulaVar mu_G_d0kpi_d0bar("mu_G_d0kpi_d0bar","","(@0*(1- @1))",RooArgList(mu_G_d0kpi, A_mu_G_d0kpi));

  RooRealVar sigma_G_d0kpi("#sigma_{G_kpi}", "sigma_gaus",9.39197e-03);
  RooRealVar A_sigma_G_d0kpi("A_{sigma_G_d0kpi}","",0);
  RooFormulaVar sigma_G_d0kpi_d0("sigma_G_d0kpi_d0","","(@0*(1 + @1))",RooArgList(sigma_G_d0kpi, A_sigma_G_d0kpi));
  RooFormulaVar sigma_G_d0kpi_d0bar("sigma_G_d0kpi_d0bar","","(@0*(1- @1))",RooArgList(sigma_G_d0kpi, A_sigma_G_d0kpi));

  RooGaussian gauss_d0kpi_d0("gauss_d0kpi_d0", "gauss component", mKK, mu_G_d0kpi_d0, sigma_G_d0kpi_d0);
  RooGaussian gauss_d0kpi_d0bar("gauss_d0kpi_d0bar", "gauss component", mKK, mu_G_d0kpi_d0bar, sigma_G_d0kpi_d0bar);
  
  RooRealVar gamma_J_d0kpi("#gamma_{J_kpi}", "gamma",-1.56041e+00,-5,5);
  RooRealVar A_gamma_J_d0kpi("A_{gamma_J_d0kpi}","",0);
  RooFormulaVar gamma_J_d0kpi_d0("gamma_J_d0kpi_d0","","(@0*(1 + @1))",RooArgList(gamma_J_d0kpi, A_gamma_J_d0kpi));
  RooFormulaVar gamma_J_d0kpi_d0bar("gamma_J_d0kpi_d0bar","","(@0*(1- @1))",RooArgList(gamma_J_d0kpi, A_gamma_J_d0kpi));

  RooRealVar delta_J_d0kpi("#delta_{J_kpi}", "delta",4.04397e-01,0,5);
  RooRealVar A_delta_J_d0kpi("A_{delta_J_d0kpi}","",0);
  RooFormulaVar delta_J_d0kpi_d0("delta_J_d0kpi_d0","","(@0*(1 + @1))",RooArgList(delta_J_d0kpi, A_delta_J_d0kpi));
  RooFormulaVar delta_J_d0kpi_d0bar("delta_K_d0kpi_d0bar","","(@0*(1- @1))",RooArgList(delta_J_d0kpi, A_delta_J_d0kpi));

  RooRealVar mu_J_d0kpi("#mu_{J_kpi}", "mean",1.96138e+00,1.94,1.98);
  RooRealVar A_mu_J_d0kpi("A_{mu_J_d0kpi}","",0);
  RooFormulaVar mu_J_d0kpi_d0("mu_J_d0kpi_d0","","(@0*(1 + @1))",RooArgList(mu_J_d0kpi, A_mu_J_d0kpi));
  RooFormulaVar mu_J_d0kpi_d0bar("mu_J_d0kpi_d0bar","","(@0*(1- @1))",RooArgList(mu_J_d0kpi, A_mu_J_d0kpi));

  RooRealVar sigma_J_d0kpi("#sigma_{J}_d0kpi", "sigma",1.19344e-02);
  RooRealVar A_sigma_J_d0kpi("A_{sigma_J_d0kpi}","",0);
  RooFormulaVar sigma_J_d0kpi_d0("sigma_J_d0kpi_d0","","(@0*(1 + @1))",RooArgList(sigma_J_d0kpi, A_sigma_J_d0kpi));
  RooFormulaVar sigma_J_d0kpi_d0bar("sigma_J_d0kpi_d0bar","","(@0*(1- @1))",RooArgList(sigma_J_d0kpi, A_sigma_J_d0kpi));

  myRooJohnsonSU johnson_d0kpi_d0("johnson_d0kpi_d0", "Johnson PDF", mKK, mu_J_d0kpi_d0, sigma_J_d0kpi_d0, delta_J_d0kpi_d0, gamma_J_d0kpi_d0);
  myRooJohnsonSU johnson_d0kpi_d0bar("johnson_d0kpi_d0bar", "Johnson PDF", mKK, mu_J_d0kpi_d0bar, sigma_J_d0kpi_d0bar, delta_J_d0kpi_d0bar, gamma_J_d0kpi_d0bar);
  
  RooAddPdf kpi_mKK_d0("kpi_mKK_d0","kpi_mKK_d0",gauss_d0kpi_d0,johnson_d0kpi_d0,f1_d0kpi_d0);
  RooAddPdf kpi_mKK_d0bar("kpi_mKK_d0bar","kpi_mKK_d0bar",gauss_d0kpi_d0bar,johnson_d0kpi_d0bar,f1_d0kpi_d0bar);
  
  //kpi peaking background
  RooProdPdf kpi_peak_d0("kpi_peak_d0", "kpi_peak_d0", kpi_mKK_d0, sig_mD0pi_d0);//as the shape of m(d0pi) is same as signal
  RooProdPdf kpi_peak_d0bar("kpi_peak_d0bar", "kpi_peak_d0bar", kpi_mKK_d0bar, sig_mD0pi_d0bar);//as the shape of m(d0pi) is same as signal
  
  //kpi & random pion
  RooProdPdf kpi_rnd_d0("kpi_rnd_d0", "kpi_rnd_d0", kpi_mKK_d0, bkg_mD0pi);
  RooProdPdf kpi_rnd_d0bar("kpi_rnd_d0bar", "kpi_rnd_d0bar", kpi_mKK_d0bar, bkg_mD0pi);

  /*-----------------------M U L T I B O D Y-------------------------*/
  RooRealVar f_J1_mult("f_{J1_mult}", "",2.30817e-01);
  RooRealVar A_f_J1_mult("A_{f_J1_mult}","",0);
  RooFormulaVar f_J1_mult_d0("f_J1_mult_d0","","(@0*(1 + @1))",RooArgList(f_J1_mult,  A_f_J1_mult));
  RooFormulaVar f_J1_mult_d0bar("f_J1_mult_d0","","(@0*(1- @1))",RooArgList(f_J1_mult, A_f_J1_mult));
 
  RooRealVar mu_J1_mult("#mu_{J1_mult}","mean_johnson",2.00641e+00);
  RooRealVar A_mu_J1_mult("A_{mu_J1_mult}","",0);
  RooFormulaVar mu_J1_mult_d0("mu_J1_mult_d0","","(@0*(1 + @1))",RooArgList(mu_J1_mult, A_mu_J1_mult));
  RooFormulaVar mu_J1_mult_d0bar("mu_J1_mult_d0bar","","(@0*(1- @1))",RooArgList(mu_J1_mult, A_mu_J1_mult));

  RooRealVar lambda_J1_mult("#lambda_{J1_mult}", "sigma_johnson",9.58128e-04);
  RooRealVar A_lambda_J1_mult("A_{lambda_J1_mult}","",0);
  RooFormulaVar lambda_J1_mult_d0("lambda_J1_mult_d0","","(@0*(1 + @1))",RooArgList(lambda_J1_mult, A_lambda_J1_mult));
  RooFormulaVar lambda_J1_mult_d0bar("lambda_J1_mult_d0bar","","(@0*(1- @1))",RooArgList(lambda_J1_mult, A_lambda_J1_mult));

  RooRealVar gamma_J1_mult("#gamma_{J1_mult}", "gamma",-3.23022e+00);
  RooRealVar A_gamma_J1_mult("A_{gamma_J1_mult}","",0);
  RooFormulaVar gamma_J1_mult_d0("gamma_J1_mult_d0","","(@0*(1 + @1))",RooArgList(gamma_J1_mult, A_gamma_J1_mult));
  RooFormulaVar gamma_J1_mult_d0bar("gamma_J1_mult_d0bar","","(@0*(1- @1))",RooArgList(gamma_J1_mult, A_gamma_J1_mult));

  RooRealVar delta_J1_mult("#delta_{J1_mult}", "delta",1.43030e-01);
  RooRealVar A_delta_J1_mult("A_{delta_J1_mult}","",0);
  RooFormulaVar delta_J1_mult_d0("delta_J1_mult_d0","","(@0*(1 + @1))",RooArgList(delta_J1_mult, A_delta_J1_mult));
  RooFormulaVar delta_J1_mult_d0bar("delta_J1_mult_d0bar","","(@0*(1- @1))",RooArgList(delta_J1_mult, A_delta_J1_mult));
 
  myRooJohnsonSU johnson1_mult_d0("johnson1_d0", "Johnson PDF", mD0pi, mu_J1_mult_d0, lambda_J1_mult_d0, delta_J1_mult_d0, gamma_J1_mult_d0);
  myRooJohnsonSU johnson1_mult_d0bar("johnson1_d0bar", "Johnson PDF", mD0pi, mu_J1_mult_d0bar, lambda_J1_mult_d0bar, delta_J1_mult_d0bar, gamma_J1_mult_d0bar);

  RooRealVar mu_J2_mult("#mu_{J2_mult}","mean_johnson",2.00524e+00);
  RooRealVar A_mu_J2_mult("A_{mu_J2_mult}","",0);
  RooFormulaVar mu_J2_mult_d0("mu_J2_mult_d0","","(@0*(1 + @1))",RooArgList(mu_J2_mult, A_mu_J2_mult));
  RooFormulaVar mu_J2_mult_d0bar("mu_J2_mult_d0bar","","(@0*(1- @1))",RooArgList(mu_J2_mult, A_mu_J2_mult));

  RooRealVar lambda_J2_mult("#lambda_{J2_mult}", "sigma_johnson",3.24842e-03 );
  RooRealVar A_lambda_J2_mult("A_{lambda_J2_mult}","",0);
  RooFormulaVar lambda_J2_mult_d0("lambda_J2_mult_d0","","(@0*(1 + @1))",RooArgList(lambda_J2_mult, A_lambda_J2_mult));
  RooFormulaVar lambda_J2_mult_d0bar("lambda_J2_mult_d0bar","","(@0*(1- @1))",RooArgList(lambda_J2_mult, A_lambda_J2_mult));

  RooRealVar delta_J2_mult("#delta_{J2_mult}", "delta",2.30106e+00);
  RooRealVar A_delta_J2_mult("A_{delta_J2_mult}","",0);
  RooFormulaVar delta_J2_mult_d0("delta_J2_mult_d0","","(@0*(1 + @1))",RooArgList(delta_J2_mult, A_delta_J2_mult));
  RooFormulaVar delta_J2_mult_d0bar("delta_J2_mult_d0bar","","(@0*(1- @1))",RooArgList(delta_J2_mult, A_delta_J2_mult));

  myRooJohnsonSU johnson2_mult_d0("johnson2_d0", "Johnson PDF", mD0pi, mu_J2_mult_d0, lambda_J2_mult_d0, delta_J2_mult_d0, gamma_J1_mult_d0);
  myRooJohnsonSU johnson2_mult_d0bar("johnson2_d0bar", "Johnson PDF", mD0pi, mu_J2_mult_d0bar, lambda_J2_mult_d0bar, delta_J2_mult_d0bar, gamma_J1_mult_d0bar);
   
  RooAddPdf mult_mD0pi_d0("mult_mD0pi_d0", "mult_mD0pi_d0", johnson1_mult_d0, johnson2_mult_d0, f_J1_mult_d0);
  RooAddPdf mult_mD0pi_d0bar("mult_mD0pi_d0bar", "mult_mD0pi_d0bar", johnson1_mult_d0bar, johnson2_mult_d0bar, f_J1_mult_d0bar);
  // myRooJohnsonSU mult_mD0pi_d0("mult_mD0pi_d0","mult_mD0pi_d0", mD0pi, mu_J_mult_d0, sigma_J_mult_d0, delta_J_mult_d0, gamma_J_mult_d0);
  // myRooJohnsonSU mult_mD0pi_d0bar("mult_mD0pi_d0bar","mult_mD0pi_d0bar", mD0pi, mu_J_mult_d0bar, sigma_J_mult_d0bar, delta_J_mult_d0bar, gamma_J_mult_d0bar);
  
  //kk
  RooRealVar a1_mult("a_{1_mult}", "A1", -1.33978e+01);
  RooRealVar A_a1_mult("A_{a1_mult}","",0);
  RooFormulaVar a1_mult_d0("a1_mult_d0","","(@0*(1 + @1))",RooArgList(a1_mult, A_a1_mult));
  RooFormulaVar a1_mult_d0bar("a1_mult_d0bar","","(@0*(1- @1))",RooArgList(a1_mult, A_a1_mult));
  
  RooExponential mult_mKK_d0("mult_mKK_d0", "mult_mKK_d0", mKK, a1_mult_d0);  
  RooExponential mult_mKK_d0bar("mult_mKK_d0bar", "mult_mKK_d0bar", mKK, a1_mult_d0bar);  

  RooProdPdf mult_peak_d0("mult_peak_d0", "mult_peak_d0", mult_mKK_d0, mult_mD0pi_d0);
  RooProdPdf mult_peak_d0bar("mult_peak_d0bar", "mult_peak_d0bar", mult_mKK_d0bar, mult_mD0pi_d0bar);
  
  //multibody & random pion
  RooProdPdf mult_rnd_d0("mult_rnd_d0","mult_rnd_d0", mult_mKK_d0, bkg_mD0pi);
  RooProdPdf mult_rnd_d0bar("mult_rnd_d0bar","mult_rnd_d0bar", mult_mKK_d0bar, bkg_mD0pi);

  /*----------------------- Ds+ -> K+ K- pi+ -------------------------*/
  //d0pi
  RooRealVar slope_ds("slope_ds", "Slope1 of Polynomial",7.55528e-01);
  RooRealVar A_slope_ds("A_{slope_ds}","",0);
  RooFormulaVar slope_ds_d0("slope_ds_d0","","(@0*(1 + @1))",RooArgList(slope_ds, A_slope_ds));
  RooFormulaVar slope_ds_d0bar("slope_ds_d0bar","","(@0*(1- @1))",RooArgList(slope_ds, A_slope_ds));

  RooChebychev ds_mD0pi_d0("ds_mD0pi_d0","Chebshev Polynomial", mD0pi,RooArgList(slope_ds_d0));
  RooChebychev ds_mD0pi_d0bar("ds_mD0pi_d0bar","Chebshev Polynomial", mD0pi,RooArgList(slope_ds_d0bar));

  //kk
  RooRealVar mu_0("#mu_{0}", "",7.06528e-06);
  RooRealVar A_mu_0("A_{mu_0}","",0);
  RooFormulaVar mu_0_d0("mu_0_d0","","(@0*(1 + @1))",RooArgList(mu_0, A_mu_0));
  RooFormulaVar mu_0_d0bar("mu_0_d0bar","","(@0*(1- @1))",RooArgList(mu_0, A_mu_0));

  RooRealVar constant("constant", "",3.83319);
  RooFormulaVar mu_ds_d0("#mu_{ds_d0}", "@0+@1-@2",RooArgList(mu_0_d0,constant, mD0pi));
  RooFormulaVar mu_ds_d0bar("#mu_{ds_d0bar}", "@0+@1-@2",RooArgList(mu_0_d0bar,constant, mD0pi));
  
  RooRealVar sigma_ds("#sigma_{ds}", "",2.88912e-03);
  RooRealVar A_sigma_ds("A_{sigma_ds}","",0);
  RooFormulaVar sigma_ds_d0("sigma_ds_d0","","(@0*(1 + @1))",RooArgList(sigma_ds, A_sigma_ds));
  RooFormulaVar sigma_ds_d0bar("sigma_ds_d0bar","","(@0*(1- @1))",RooArgList(sigma_ds, A_sigma_ds));

  RooRealVar gamma_ds("#gamma_{ds}", "",0);
  RooRealVar A_gamma_ds("A_{gamma_ds}","",0);
  RooFormulaVar gamma_ds_d0("gamma_ds_d0","","(@0*(1 + @1))",RooArgList(gamma_ds, A_gamma_ds));
  RooFormulaVar gamma_ds_d0bar("gamma_ds_d0bar","","(@0*(1- @1))",RooArgList(gamma_ds, A_gamma_ds));

  RooRealVar delta_ds("#delta_{ds}", "",6.47505e-01);
  RooRealVar A_delta_ds("A_{delta_ds}","",0);
  RooFormulaVar delta_ds_d0("delta_ds_d0","","(@0*(1 + @1))",RooArgList(delta_ds, A_delta_ds));
  RooFormulaVar delta_ds_d0bar("delta_ds_d0bar","","(@0*(1- @1))",RooArgList(delta_ds, A_delta_ds));

  myRooJohnsonSU ds_mKK_d0("ds_mKK_d0","ds_mKK_d0",mKK, mu_ds_d0,sigma_ds_d0,delta_ds_d0,gamma_ds_d0);
  myRooJohnsonSU ds_mKK_d0bar("ds_mKK_d0bar","ds_mKK_d0bar",mKK, mu_ds_d0bar,sigma_ds_d0bar,delta_ds_d0bar,gamma_ds_d0bar);
 
  RooProdPdf ds_peak_d0("ds_peak_d0", "ds_peak_d0", ds_mD0pi_d0, Conditional(ds_mKK_d0, mKK));  
  RooProdPdf ds_peak_d0bar("ds_peak_d0bar", "ds_peak_d0bar", ds_mD0pi_d0bar, Conditional(ds_mKK_d0bar, mKK));

  /*------------------------C O M B I N A T O R I A L----------------------------*/

  RooRealVar c("c_{comb}", "Slope1 of Polynomial",-2.97793e-01, -1,1);
  RooRealVar A_c("A_{c}","",0);
  RooFormulaVar c_d0("c_d0","","(@0*(1 + @1))",RooArgList(c, A_c));
  RooFormulaVar c_d0bar("c_d0bar","","(@0*(1- @1))",RooArgList(c, A_c));

  RooChebychev comb_mKK_d0("chebpol_d0","Chebshev Polynomial", mKK,RooArgList(c_d0));
  RooChebychev comb_mKK_d0bar("chebpol_d0bar","Chebshev Polynomial", mKK,RooArgList(c_d0bar));
  
  RooProdPdf comb_bkg_d0("comb_bkg_d0", "comb_bkg_d0", comb_mKK_d0, bkg_mD0pi);
  RooProdPdf comb_bkg_d0bar("comb_bkg_d0bar", "comb_bkg_d0bar", comb_mKK_d0bar, bkg_mD0pi);

/*------------------------Y I E L D S  F O R  A L L  C O M P O N E N T S----------------------------*/
  //yields
  RooRealVar sig_peak_yield("N_{sig_peak}","signal yield",3.11193e+05,1e1,1e7);
  RooRealVar sig_randompi_yield("N_{sig_rnd}","signal + random-pi yield",2.97894e+04,1e1,1e7); 
  RooRealVar kpi_peak_yield("N_{kpi_peak}","kpi yield",2.43824e+05,1e1,1e7);
  RooRealVar kpi_randompi_yield("N_{kpi_rnd}","kpi + random-pi yield",1.77728e+04,1e1,1e7);
  RooRealVar mult_peak_yield("N_{mult_peak}","multibody yield",1.76241e+05,1e1,1e7);
  RooRealVar mult_randompi_yield("N_{mult_rnd}","multibody + random-pi yield",1.99614e+04,1e1,1e5); 
  RooRealVar ds_peak_yield("N_{ds_peak}","ds yield",8.10195e+03,1e1,1e7);  
  RooRealVar comb_yield("N_{comb}","combinatorial yield",2.67173e+05,0.,1e7);
  
  //Asymmetries
  RooRealVar Araw_sig("A_{sig}","Araw",0,-1,1);
  RooRealVar Araw_sig_randompi("A_{sig_randompi}","Araw",0,-1,1);
  RooRealVar Araw_kpi("A_{kpi}","Araw",0,-1,1);
  RooRealVar Araw_kpi_randompi("A_{kpi_randompi}","Araw",0,-1,1);
  RooRealVar Araw_mult("A_{mult}","Araw",0,-1,1);
  RooRealVar Araw_mult_randompi("A_{mult_randompi}","Araw",0,-1,1);
  RooRealVar Araw_ds("A_{Ds}","Araw",0,-1,1);
  RooRealVar Araw_comb("A_{comb}","Araw",0,-1,1);

  //Yields for D0 sample: ND0 = N(1+A)/2
  RooFormulaVar sig_peak_yield_d0("ND0_{sig_peak}","(@0*(1 + @1))/2",RooArgList(sig_peak_yield,Araw_sig));
  RooFormulaVar sig_randompi_yield_d0("ND0_{sig_rnd}","(@0*(1 + @1))/2",RooArgList(sig_randompi_yield,Araw_sig_randompi));
  RooFormulaVar kpi_peak_yield_d0("ND0_{kpi_peak}","(@0*(1 + @1))/2",RooArgList(kpi_peak_yield,Araw_kpi));
  RooFormulaVar kpi_randompi_yield_d0("ND0_{kpi_rnd}","(@0*(1 + @1))/2",RooArgList(kpi_randompi_yield,Araw_kpi_randompi));
  RooFormulaVar mult_peak_yield_d0("ND0_{mult_peak}","(@0*(1 + @1))/2",RooArgList(mult_peak_yield,Araw_mult));
  RooFormulaVar mult_randompi_yield_d0("ND0_{mult_rnd}","(@0*(1 + @1))/2",RooArgList(mult_randompi_yield,Araw_mult_randompi));
  RooFormulaVar ds_peak_yield_d0("ND0_{ds_peak}","(@0*(1 + @1))/2",RooArgList(ds_peak_yield,Araw_ds));
  RooFormulaVar comb_yield_d0("ND0_{comb}","(@0*(1 + @1))/2",RooArgList(comb_yield,Araw_comb));
  
  //Yields for D0bar sample: ND0bar = N(1-A)/2
  RooFormulaVar sig_peak_yield_d0bar("ND0bar_{sig_peak}","(@0*(1 - @1))/2",RooArgList(sig_peak_yield,Araw_sig));
  RooFormulaVar sig_randompi_yield_d0bar("ND0bar_{sig_rnd}","(@0*(1 - @1))/2",RooArgList(sig_randompi_yield,Araw_sig_randompi));
  RooFormulaVar kpi_peak_yield_d0bar("ND0bar_{kpi_peak}","(@0*(1 - @1))/2",RooArgList(kpi_peak_yield,Araw_kpi));
  RooFormulaVar kpi_randompi_yield_d0bar("ND0bar_{kpi_rnd}","(@0*(1 - @1))/2",RooArgList(kpi_randompi_yield,Araw_kpi_randompi));
  RooFormulaVar mult_peak_yield_d0bar("ND0bar_{mult_peak}","(@0*(1 - @1))/2",RooArgList(mult_peak_yield,Araw_mult));
  RooFormulaVar mult_randompi_yield_d0bar("ND0bar_{mult_rnd}","(@0*(1 - @1))/2",RooArgList(mult_randompi_yield,Araw_mult_randompi));
  RooFormulaVar ds_peak_yield_d0bar("ND0bar_{ds_peak}","(@0*(1 - @1))/2",RooArgList(ds_peak_yield,Araw_ds));
  RooFormulaVar comb_yield_d0bar("ND0bar_{comb}","(@0*(1 - @1))/2",RooArgList(comb_yield,Araw_comb));
   
  /*------------------------C O M P L E T E  M O D E L----------------------------*/

  RooAddPdf model_d0("model_d0","",RooArgList(signal_peak_d0,signal_rnd_d0,kpi_peak_d0,kpi_rnd_d0,mult_peak_d0,mult_rnd_d0,ds_peak_d0,comb_bkg_d0), RooArgList(sig_peak_yield_d0,sig_randompi_yield_d0,kpi_peak_yield_d0,kpi_randompi_yield_d0,mult_peak_yield_d0, mult_randompi_yield_d0,ds_peak_yield_d0,comb_yield_d0));
  RooAddPdf model_d0bar("model_d0bar","",RooArgList(signal_peak_d0bar,signal_rnd_d0bar,kpi_peak_d0bar,kpi_rnd_d0bar,mult_peak_d0bar,mult_rnd_d0bar,ds_peak_d0bar,comb_bkg_d0bar), RooArgList( sig_peak_yield_d0bar, sig_randompi_yield_d0bar, kpi_peak_yield_d0bar,kpi_randompi_yield_d0bar,mult_peak_yield_d0bar, mult_randompi_yield_d0bar,ds_peak_yield_d0bar,comb_yield_d0bar));

  //Define category to distinguish d0 and d0bar samples events
  RooCategory sample("sample","sample") ;
  sample.defineType("D0");
  sample.defineType("D0bar");

  //Construct combined dataset
  // RooDataSet combData("combData","combined data",RooArgSet(mKK, mD0pi, weights),Index(sample),Import("D0",*dataxy_d0),Import("D0bar",*dataxy_d0bar),WeightVar("weights"));

  //Construct a simultaneous pdf using category sample as index
  RooSimultaneous simPdf("simPdf","simultaneous pdf",sample) ;
  simPdf.addPdf(model_d0,"D0") ;
  simPdf.addPdf(model_d0bar,"D0bar");

  // Construct combined dataset
  // RooDataSet combData("combData","combined data",RooArgSet(mKK, mD0pi, weights),Index(sample),Import("D0",*dataxy_d0),Import("D0bar",*dataxy_d0bar),WeightVar("weights"));

  //Perform the simultaneous fit
  // simPdf.fitTo(combData,Strategy(2), SumW2Error(true));

  
  /*------------------------ R O O  M C  S T U D Y  ----------------------------*/
  
  // RooMCStudy *mcs = new RooMCStudy(simPdf, RooArgSet(mD0pi,mKK, weights, sample), Extended(), Silence(), FitOptions(Save(kTRUE), PrintEvalErrors(0)));
  RooMCStudy *mcs = new RooMCStudy(simPdf, RooArgSet(mD0pi,mKK,weights,sample), Extended(), Silence(), FitOptions(Save(kTRUE), PrintEvalErrors(-1),BatchMode(true), Strategy(0))); 
  // mcs->generateAndFit(500); 
  mcs->generateAndFit(10);   
  //mcs->fitParDataSet().Print("v");

  // Make plot of distribution of generated value of A_{raw_sif} parameter
  TH1* h_f_gen = mcs->fitParDataSet().createHistogram("A_{sig}", -40) ;

  RooPlot* frame1  = mcs->plotParam(Araw_sig, Bins(100));
  RooDataSet af1 = mcs->fitParDataSet(); af1.statOn(frame1);
  frame1->SetTitle("raw asymmetry in signal") ;

  RooPlot* frame2 = mcs->plotError(Araw_sig, Bins(100));
  RooDataSet af2 = mcs->fitParDataSet(); af2.statOn(frame2);
  frame2->SetTitle("uncertainty on raw asymmetry in signal");

  RooPlot* frame3 = mcs->plotPull(Araw_sig, Bins(100),FitGauss(false)) ;
  RooDataSet af3 = mcs->fitParDataSet(); af3.statOn(frame3);
  frame3->SetTitle("pulls");

  RooPlot* frame4  = mcs->plotParam(sig_peak_yield, Bins(100));
  RooDataSet af4 = mcs->fitParDataSet(); af4.statOn(frame4);
  frame4->SetTitle("signal yield");

  RooPlot* frame5 = mcs->plotError(sig_peak_yield, Bins(100));
  RooDataSet af5 = mcs->fitParDataSet(); af5.statOn(frame5);
  frame5->SetTitle("uncertainty on signal yield");

  RooPlot* frame6 = mcs->plotPull(sig_peak_yield, Bins(100),FitGauss(false));
  RooDataSet af6 = mcs->fitParDataSet(); af6.statOn(frame6);
  frame6->SetTitle("pulls");


  TCanvas* canvas = new TCanvas("TestPulls","TestPulls",1200,800);
  canvas->Divide(3, 2) ;
  canvas->cd(1) ; gPad->SetLeftMargin(0.15) ; frame1->GetYaxis()->SetTitleOffset(1.4) ; frame1->Draw();
  canvas->cd(2) ; gPad->SetLeftMargin(0.15) ; frame2->GetYaxis()->SetTitleOffset(1.4) ; frame2->Draw();
  canvas->cd(3) ; gPad->SetLeftMargin(0.15) ; frame3->GetYaxis()->SetTitleOffset(1.4) ; frame3->Draw();
  canvas->cd(4) ; gPad->SetLeftMargin(0.15) ; frame4->GetYaxis()->SetTitleOffset(1.4) ; frame4->Draw();
  canvas->cd(5) ; gPad->SetLeftMargin(0.15) ; frame5->GetYaxis()->SetTitleOffset(1.4) ; frame5->Draw();
  canvas->cd(6) ; gPad->SetLeftMargin(0.15) ; frame6->GetYaxis()->SetTitleOffset(1.4) ; frame6->Draw();
  // Make RooMCStudy object available on command line after macro finishes
  gDirectory->Add(mcs);

  ////////////////////////////////////////////////////////////

  

}





 
















